import java.awt.Frame;
import java.awt.Image;
import java.awt.Color;
import java.awt.Graphics;
import Drawing;


/**
 * This class demonstrates how to use the Drawing class to create and display
 * drawing.
 * This version of GetImage is for CoPlot version 6.003 and below.
 */
public class GetImage1 extends Frame {

  public static void main(String args[]) {
    String error; 
    Image image;
    Graphics graphics;

    //create and display the program's Frame
    Frame frame=new GetImage1();
    frame.setBounds(0,0, 600, 600); //arbitrary size
    frame.setVisible(true);
    
    //create an instance of Drawing
    Drawing drawing=new Drawing("YourName", "RegistrationNumber");

    //specify what will be drawn for the first drawing
    //this is the equivalent of the "sample.draw" file
    drawing.setXBounds(0, 4.5);
    drawing.setYBounds(4.5, 10);
    drawing.setLeftMargin(2);
    drawing.setBottomMargin(2.85);
    drawing.setMinimumLineWidth(0.003);

    drawing.createDatafile(1);
    drawing.datafile.insertRows(1,3);
    drawing.datafile.insertColumn(1, "d", "X");
    drawing.datafile.insertColumn(2, "d", "Y");
    drawing.datafile.setRow(1, "1.5, 0.5");
    drawing.datafile.setRow(2, "3, 4");
    drawing.datafile.setRow(3, "8.5, 9.5");

    drawing.setCharacters("");
    drawing.newGraph();
    drawing.graph.title.text("\"Sample Drawing\", \".\"");
    drawing.graph.dataset.setNDatasets(1);
    drawing.graph.dataset.representation("13");
    drawing.create("graph", "2.09, 8.04");

    drawing.setLineColor(Color2.green4);
    drawing.setLineType(0);
    drawing.setLineDashsize(0.02);
    drawing.setLineWidth(0.01);
    drawing.setPathType(0);
    drawing.create("path", "0.97, 5.08, 2.23, 6.14, 3.76, 5.64");

    drawing.setCharacters("");
    drawing.setBackgroundColor(Color2.yellow4);
    drawing.setFillColor(Color2.blue4);
    drawing.setFillType(1);
    drawing.setFillSize(0.1);
    drawing.setFillLinewidth(0.01);
    drawing.setLineColor(Color2.orange4);
    drawing.setLineWidth(0.02);
    drawing.setEllipseSize(0.5);
    drawing.setEllipseInnerSize(0);
    drawing.setEllipseWidth(1);
    drawing.setEllipseStart(0);
    drawing.setEllipseFinish(360);
    drawing.setEllipseNSides(90);
    drawing.setEllipseAngle(0);
    drawing.setEllipseSkew(0);
    drawing.create("ellipse", "2.04, 5.71");

    //create an image of the appropriate size 
    //  (based on drawing.setXBounds() and drawing.setYBounds())
    //  and render the drawing on it
    //An error here isn't necessarily serious. The resulting image
    //  may be complete, partial (full size, but with something unexpected), 
    //  or null.
    resetPath(nps.getFullWidth(), nps.getFullHeight());
    if (nps.getImage()==null)
      System.err.println(
        "Drawing.fileSaveAsImage:\nNot enough memory to create the image.");
    else {
      //draw the drawing onto the image
      error=drawing.drawAll();
      if (error.length()>0) System.err.println(error);
    
      //then grab the Image and display it
      //If the image is null, the error message was displayed above.
      //20= shift image down to avoid the frame's titleBar.
      image=drawing.nps.getImage();
      if (image!=null) frame.getGraphics().drawImage(image, 0, 20, null);

      //sleep for 5 seconds
      try {Thread.sleep(5000); } catch (Throwable t) {}
      }


    //clear the frame
    graphics=frame.getGraphics();
    graphics.setColor(Color.white);
    graphics.fillRect(0,0, 600, 600); 

    //clear the drawing specification in preparation for the 2nd drawing
    drawing.reset();             

    //Specify what will be drawn for the 2nd drawing.
    //This can be more drawing.xxx commands, as above, 
    //  or you can import a drawing (from many different types of files). 
    //In this example, we will import a .gif file.
    //7=.gif: See the Drawing program documentation for a list of file types.
    //The "cohort" property contains the directory with the cohort files.
    error=drawing.fileOpen(7, System.getProperty("cohort")+"parts.gif");

    //create an image of the appropriate size 
    //  (based on drawing.setXBounds() and drawing.setYBounds())
    //  and render the drawing on it
    //An error here isn't necessarily serious. The resulting image
    //  may be complete, partial (full size, but with something unexpected), 
    //  or null.
    resetPath(nps.getFullWidth(), nps.getFullHeight());
    if (nps.getImage()==null)
      System.err.println(
        "Drawing.fileSaveAsImage:\nNot enough memory to create the image.");
    else {
      //draw the drawing onto the image
      error=drawing.drawAll();
      if (error.length()>0) System.err.println(error);
    
      //then grab the Image and display it
      //If the image is null, the error message was displayed above.
      //20= shift image down to avoid the frame's titleBar.
      image=drawing.nps.getImage();
      if (image!=null) frame.getGraphics().drawImage(image, 0, 20, null);

      //sleep for 5 seconds
      try {Thread.sleep(5000); } catch (Throwable t) {}
      }


    //shut down the program
    System.exit(0); 
    }
  }
